@@ -14,6 +14,8 @@ TEST_SERVER = True
 CONTACT_EMAIL = 'mail@email.com'
 # If websockets is running on a non-standard port, add it here:
 WS_PORT = False
+# Interval between document saves
+DOC_SAVE_INTERVAL = 1
 
 ADMINS = (
     ('Your Name', 'your_email@example.com'),
@@ -32,7 +34,7 @@ DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
         'NAME': os.path.join(PROJECT_PATH, 'fiduswriter.sql'),
-        'CONN_MAX_AGE': 15
+        'CONN_MAX_AGE': None
     }
 }
 
@@ -40,9 +42,13 @@ DATABASES = {
 # simultaneously
 DATA_UPLOAD_MAX_NUMBER_FIELDS = 5000
 
-# Whether anyone surfing to the site can open an account.
+# Whether anyone surfing to the site can open an account with a login/password.
 REGISTRATION_OPEN = True
 
+# Whether anyone surfing to the site can open an account or login with a
+# socialaccount.
+SOCIALACCOUNT_OPEN = True
+
 # This determines whether there is a star labeled "Free" on the login page
 IS_FREE = True
 
@@ -174,6 +180,7 @@ TEMPLATES = [
 # The following are the apps needed by Fidus Writer.
 
 BASE_INSTALLED_APPS = [
+    'npm_mjs',
     'base',
     'django.contrib.auth',
     'django.contrib.contenttypes',
@@ -185,7 +192,6 @@ BASE_INSTALLED_APPS = [
     'django.contrib.admindocs',
     'django.contrib.flatpages',
     'django_js_error_hook',
-    'npm_mjs',
     'fixturemedia',
     'browser_check',
     'menu',
@@ -332,8 +338,18 @@ JAVASCRIPT_ERROR_USERAGENT_BLACKLIST = ['googlebot', 'bingbot', 'cutycapt']
 JAVASCRIPT_ERROR_BLACKLIST = [
     'script error',
     'the operation is insecure',
-    'parse error'
+    'parse error',
+    'unhandledrejection, {}',
 ]
 
 # The page to show while transpilation takes place.
 SETUP_PAGE_PATH = os.path.join(SRC_PATH, 'base/setup_page/')
+
+# Whether to use the old JSON patch method rather than prosemirror-py.
+# Tests have shown that the JSON patch method is faster for now. This setting
+# will likely be removed once the prosemirror-py method has reached a similar
+# speed.
+JSONPATCH = True
+
+# Whether to create a service worker on production sites
+USE_SERVICE_WORKER = True
