@@ -13,6 +13,12 @@ class Command(BaseCommand):
     help = 'Check JavaScript files with ESLint'
 
     def add_arguments(self, parser):
+        parser.add_argument(
+            'dir',
+            nargs='?',
+            default='.',
+            help='Directory to check'
+        )
         parser.add_argument(
             '--fix',
             action='store_true',
@@ -22,6 +28,7 @@ class Command(BaseCommand):
         )
 
     def handle(self, *args, **options):
+        self.stdout.write("Linting JavaScript code...")
         call_command("npm_install")
         shutil.os.chdir(settings.PROJECT_PATH)
         apps_paths = []
@@ -44,7 +51,7 @@ class Command(BaseCommand):
                 settings.SRC_PATH,
                 ".eslintrc.js"
             ),
-            "."
+            options['dir'],
         ]
         if options['fix']:
             command_array.append('--fix')
