@@ -10,7 +10,7 @@ const baseRule = {
         loader: "babel-loader",
         options: {
             presets: ["@babel/preset-env"],
-            plugins: ["@babel/plugin-syntax-dynamic-import"]
+            plugins: ["@babel/plugin-syntax-dynamic-import", "@babel/plugin-proposal-optional-chaining"]
         }
     }
 }
@@ -50,6 +50,7 @@ module.exports = { // eslint-disable-line no-undef
         new webpack.DefinePlugin({
             "settings_STATIC_URL": JSON.stringify(settings.STATIC_URL),
             "settings_REGISTRATION_OPEN": settings.REGISTRATION_OPEN,
+            "settings_SOCIALACCOUNT_OPEN": settings.SOCIALACCOUNT_OPEN,
             "settings_CONTACT_EMAIL": JSON.stringify(settings.CONTACT_EMAIL),
             "settings_WS_SERVER": settings.WS_SERVER ? JSON.stringify(settings.WS_SERVER) : false,
             "settings_WS_PORT": settings.WS_PORT,
@@ -57,6 +58,8 @@ module.exports = { // eslint-disable-line no-undef
             "settings_TEST_SERVER": settings.TEST_SERVER,
             "settings_DEBUG": settings.DEBUG,
             "settings_SOURCE_MAPS": JSON.stringify(settings.SOURCE_MAPS) || false,
+            "settings_USE_SERVICE_WORKER": settings.USE_SERVICE_WORKER,
+            "settings_JSONPATCH": settings.JSONPATCH,
             "transpile_VERSION": transpile.VERSION
         }),
         new OfflinePlugin({
@@ -77,7 +80,8 @@ module.exports = { // eslint-disable-line no-undef
             ],
             ServiceWorker: {
                 publicPath: '/sw.js',
-                events: true
+                events: true,
+                entry: "./js/sw-template.js"
             },
             autoUpdate: true,
             appShell: "/",
@@ -93,6 +97,7 @@ module.exports = { // eslint-disable-line no-undef
             excludes: [
                 'admin_console.js',
                 'maintenance.js',
+                'schema_export.js',
                 'test_caret.js',
                 'document_template_admin.js',
                 '**/.*',
