@@ -2,5 +2,7 @@ export {HeaderbarView, headerbarModel} from "./headerbar"
 export {ToolbarView, toolbarModel} from "./toolbar"
 export {SelectionMenuView, selectionMenuModel} from "./selection"
 export {tableMenuModel} from "./table"
+export {orderedListMenuModel} from "./ordered_list"
 export {imageMenuModel} from "./image"
 export {navigatorFilterModel} from "./navigator"
+export {figureMenuModel} from "./figure"
