@@ -30,7 +30,8 @@ export {
 }
     from "./comments"
 export {
-    documentTemplatePlugin
+    documentTemplatePlugin,
+    checkProtectedInSelection
 }
     from "./document_template"
 export {
@@ -58,6 +59,10 @@ export {
     marginboxesPlugin
 }
     from "./marginboxes"
+export {
+    orderedListMenuPlugin
+}
+    from "./ordered_list_menu"
 export {
     placeholdersPlugin
 }
@@ -71,9 +76,9 @@ export {
 }
     from "./settings"
 export {
-    tableMenuPlugin
+    tablePlugin
 }
-    from "./table_menu"
+    from "./table"
 export {
     figurePlugin
 }
@@ -107,4 +112,4 @@ export {
     deselectSearchMatch,
     endSearch
 }
-    from "./search"
\ No newline at end of file
+    from "./search"
