@@ -4,18 +4,20 @@ import {ReplaceStep, ReplaceAroundStep, AddMarkStep, RemoveMarkStep, Mapping} fr
 import {CellSelection} from "prosemirror-tables"
 
 function markInsertion(tr, from, to, user, date1, date10, approved) {
-    tr.removeMark(from, to, tr.doc.type.schema.marks.deletion)
-    tr.removeMark(from, to, tr.doc.type.schema.marks.insertion)
     const insertionMark = tr.doc.type.schema.marks.insertion.create({user: user.id, username: user.username, date: date10, approved})
-    tr.addMark(from, to, insertionMark)
     // Add insertion mark also to block nodes (figures, text blocks) but not table cells/rows and lists.
     tr.doc.nodesBetween(
         from,
         to,
         (node, pos) => {
-            if (pos < from || ['bullet_list', 'ordered_list'].includes(node.type.name)) {
+            if (node.isInline) {
+                tr.removeMark(Math.max(from, pos), Math.min(pos + node.nodeSize, to), tr.doc.type.schema.marks.deletion)
+                tr.removeMark(Math.max(from, pos), Math.min(pos + node.nodeSize, to), tr.doc.type.schema.marks.insertion)
+                tr.addMark(Math.max(from, pos), Math.min(pos + node.nodeSize, to), insertionMark)
+                return false
+            } else if (pos < from || ['bullet_list', 'ordered_list'].includes(node.type.name)) {
                 return true
-            } else if (node.isInline || ['table_row', 'table_cell'].includes(node.type.name)) {
+            } else if (['table_row', 'table_cell'].includes(node.type.name)) {
                 return false
             }
             if (node.attrs.track) {
@@ -25,8 +27,8 @@ function markInsertion(tr, from, to, user, date1, date10, approved) {
                 }
                 tr.setNodeMarkup(pos, null, Object.assign({}, node.attrs, {track}), node.marks)
             }
-            if (node.type.name === 'table') {
-                // A table was inserted. We don't add track marks to elements inside of it.
+            if (['figure', 'table'].includes(node.type.name)) {
+                // A table or figure was inserted. We don't add track marks to elements inside of it.
                 return false
             }
         }
@@ -66,11 +68,10 @@ function markDeletion(tr, from, to, user, date1, date10) {
                     deletionMark
                 )
             } else if (
-                node.attrs.track &&
-                !node.attrs.track.find(trackAttr => trackAttr.type === 'deletion') &&
+                !node.attrs.track?.find(trackAttr => trackAttr.type === 'deletion') &&
                 !['bullet_list', 'ordered_list'].includes(node.type.name)
             ) {
-                if (node.attrs.track.find(trackAttr => trackAttr.type === 'insertion' && trackAttr.user === user.id)) {
+                if (node.attrs.track?.find(trackAttr => trackAttr.type === 'insertion' && trackAttr.user === user.id)) {
                     let removeStep
                     // user has created element. so (s)he is allowed to delete it again.
                     if (node.isTextblock && to < (pos + node.nodeSize)) {
@@ -94,11 +95,14 @@ function markDeletion(tr, from, to, user, date1, date10) {
                     if (!tr.maybeStep(removeStep).failed) {
                         deletionMap.appendMap(removeStep.getMap())
                     }
-                } else {
+                } else if (node.attrs.track) {
                     const track = node.attrs.track.slice()
                     track.push({type: 'deletion', user: user.id, username: user.username, date: date1})
                     tr.setNodeMarkup(deletionMap.map(pos), null, Object.assign({}, node.attrs, {track}), node.marks)
                 }
+                if (node.type.name === 'figure') {
+                    return false
+                }
             }
         }
     )
@@ -168,7 +172,7 @@ export function trackedTransaction(tr, state, user, approved, date) {
         date10 = Math.floor(date / 600000) * 10, // 10 minute interval
         date1 = Math.floor(date / 60000), // 1 minute interval
         // We only insert content if this is not directly a tr for cell deletion. This is because tables delete rows by deleting the
-        // contents of each cell and replacing it with an empty paragraph.
+        // content of each cell and replacing it with an empty paragraph.
         cellDeleteTr = ['deleteContentBackward', 'deleteContentForward'].includes(tr.getMeta('inputType')) && (state.selection instanceof CellSelection)
 
     tr.steps.forEach((originalStep) => {
@@ -212,7 +216,7 @@ export function trackedTransaction(tr, state, user, approved, date) {
                 const mirrorIndex = map.maps.length - 1
                 map.appendMap(condensedStep.getMap(), mirrorIndex)
                 if (!newTr.selection.eq(trTemp.selection)) {
-                    newTr.setSelection(trTemp.selection)
+                    newTr.setSelection(newTr.doc, Selection.fromJSON(trTemp.selection.toJSON()))
                 }
             }
             if (!approved && step.from !== step.to) {
