@@ -1,7 +1,7 @@
 import {PAPER_SIZES} from "../../schema/const"
 import {HTMLExporter} from "../html"
 import {addAlert} from "../../common"
-import {removeHidden} from "../tools/doc_contents"
+import {removeHidden} from "../tools/doc_content"
 import {printHTML} from "@vivliostyle/print"
 
 export class PrintExporter extends HTMLExporter {
@@ -24,20 +24,20 @@ export class PrintExporter extends HTMLExporter {
 
             }
             body, section[role=doc-footnotes] {
-                counter-reset: figure-cat-0 figure-cat-1 figure-cat-2 footnote-counter footnote-marker-counter;
+                counter-reset: cat-0 cat-1 cat-2 footnote-counter footnote-marker-counter;
             }
             section[role=doc-footnote] > *:first-child:before {
                 counter-increment: footnote-counter;
                 content: counter(footnote-counter) ". ";
             }
-            section[role=doc-footnote] .figure-cat-figure::after {
-                content: ' ' counter(figure-cat-0) 'A';
+            section[role=doc-footnote] figure[data-category='figure'] caption label::after {
+                content: ' ' counter(cat-0) 'A';
             }
-            section[role=doc-footnote] .figure-cat-photo::after {
-                content: ' ' counter(figure-cat-1) 'A';
+            section[role=doc-footnote] figure[data-category='photo']::after {
+                content: ' ' counter(cat-1) 'A';
             }
-            section[role=doc-footnote] .figure-cat-table::after {
-                content: ' ' counter(figure-cat-2) 'A';
+            section[role=doc-footnote] figure[data-category='table']::after {
+                content: ' ' counter(cat-2) 'A';
             }
             section.fnlist {
                 display: none;
@@ -85,7 +85,7 @@ export class PrintExporter extends HTMLExporter {
 
     init() {
         addAlert('info', `${this.doc.title}: ${gettext('Printing has been initiated.')}`)
-        this.docContents = removeHidden(this.doc.contents, false)
+        this.docContent = removeHidden(this.doc.content, false)
         this.addDocStyle(this.doc)
 
         return this.loadStyles().then(
