@@ -4,6 +4,8 @@ import sys
 from importlib import import_module
 
 from django.conf import settings
+from django.db import connections
+
 
 if "COVERAGE_PROCESS_START" in os.environ:
     import coverage
@@ -16,18 +18,30 @@ os.environ.setdefault(
 )
 
 
+# The following lines are needed until Tornado supports ASGI or Tornado has
+# been replaced.
+class Connections:
+    pass
+
+
+os.environ["DJANGO_ALLOW_ASYNC_UNSAFE"] = "true"
+setattr(connections, '_connections', Connections)
+
+
 def inner(default_project_path):
     sys.path.append(SRC_PATH)
     sys_argv = sys.argv
-    if '--pythonpath' in sys_argv:
+    PROJECT_PATH = False
+    while '--pythonpath' in sys_argv:
         index = sys_argv.index('--pythonpath')
         PROJECT_PATH = os.path.join(os.getcwd(), sys_argv[index + 1])
+        sys.path.insert(0, PROJECT_PATH)
         # We prevent the pythonpath to be handled later on by removing it from
         # sys_argv
         sys_argv = sys_argv[:index] + sys_argv[index+2:]
-    else:
+    if not PROJECT_PATH:
         PROJECT_PATH = default_project_path
-    sys.path.insert(0, PROJECT_PATH)
+        sys.path.insert(0, PROJECT_PATH)
     os.environ.setdefault(
         "PROJECT_PATH",
         PROJECT_PATH
